@@ -4,7 +4,6 @@ set -x
 
 exec 2>&1 > upgrade.log
 
-sudo apt-get update
-sudo apt-get upgrade -y
+sudo apt-get full-upgrade -y
 
 exit 0
