@@ -18,7 +18,10 @@ meas.message = function(text, type, timeout) {
     var div = document.createElement('div')
     div.innerHTML = '<div class="msg ' + type + '"><span>x</span><span>' + text + '</span></div>'
     var cancel = function(ev) {
-	div.parentElement.removeChild(div)
+	div.innerHTML = ''
+	if (div.parentElement) {
+	    div.parentElement.removeChild(div)
+	}
     }
     div.onclick = cancel
     var target = document.querySelector('#' + meas.msgElemId)
@@ -29,18 +32,19 @@ meas.message = function(text, type, timeout) {
 	}
     }
     console.log('meas:' + type + ': ' + text)
+    return cancel
 }
 
 meas.note = function(text, timeout) {
     if (!timeout) timeout = 2
-    meas.message(text, 'note', timeout)
+    return meas.message(text, 'note', timeout)
 }
 meas.warning = function(text, timeout) {
     if (!timeout) timeout = 3
-    meas.message(text, 'warning', timeout)
+    return meas.message(text, 'warning', timeout)
 }
 meas.error = function(text, timeout) {
-    meas.message(text, 'error', timeout)
+    return meas.message(text, 'error', timeout)
 }
 
 meas.updateControls = function(dummy) {
@@ -97,9 +101,12 @@ meas.doUpdateControls1 = function() {
     dispSelectButtons += '<button class="' + class_3 + ' tlt" onclick="meas.loadTable()">Measurements as table</button>'
     grtempcols += ' auto'
 
-    xc.inject('result-dispsels',
-	      '<div class="settingssubmenu" style="grid-template-columns: ' + grtempcols + ';">' + dispSelectButtons + '</div>'
-	     )
+    var html = ''
+    if (document.querySelector('#live-view') == null) {
+	html += '<a class="xc-nocatch tlt" href="#" onclick="meas.hideResultView()">Close</a></br>'
+    }
+    html += '<div class="settingssubmenu" style="grid-template-columns: ' + grtempcols + ';">' + dispSelectButtons + '</div>'
+    xc.inject('result-dispsels', html)
 }
 
 meas.doUpdateControls3 = function() {
@@ -211,6 +218,10 @@ meas.loadMeasurement = function(fname) {
     })
 }
 
+meas.loadSlowMeasurement = function(fname) {
+    meas.loadMeasurement(fname.split('-slow').join(''))
+}
+
 meas.parseMeasurementArray = function(a) {
     var ddict = {}
     Object.keys(meas.headerInfo.names).map((k) => {
@@ -222,7 +233,7 @@ meas.parseMeasurementArray = function(a) {
 
 meas.show = function(ref) {
     var el = document.querySelector(ref)
-    if (el) el.style['display'] = ''
+    if (el) el.style.removeProperty('display')
 }
 
 meas.hide = function(ref) {
@@ -230,6 +241,13 @@ meas.hide = function(ref) {
     if (el) el.style['display'] = 'none'
 }
 
+meas.hideChildren = function(ref) {
+    var el = document.querySelector(ref).children
+    for (var k = 0; k < el.length; ++k) {
+	el[k].style['display'] = 'none'
+    }
+}
+
 meas.updateView = function() {
     if (meas.mode == 'table') {
 	meas.loadTable()
@@ -310,10 +328,14 @@ meas.inint = function(a, v) {
     return a[1] > v && a[0] <= v
 }
 
-meas.ininttr = function(a, v) {
+meas.encininttr = function(a, v) {
     return a[1] > v.max && a[0] <= v.min
 }
 
+meas.ininttr = function(a, v) {
+    return !(a[0] > v.max || a[1] < v.min)
+}
+
 meas.findint = function(ints, v) {
     var res = -1
     Object.keys(ints).forEach((k) => {
@@ -325,12 +347,25 @@ meas.findint = function(ints, v) {
     return res
 }
 
-meas.findinttr = function(ints, v) {
-    var res = -1
+meas.findinttrgns = function(ints, v) {
+    var res = []
     Object.keys(ints).forEach((k) => {
 	var intv = ints[k]
 	if (meas.ininttr(intv, v)) {
-	    res = k
+	    res.push(k-2)
+	}
+    })
+    return res
+}
+
+meas.findinttr = function(ints, v) {
+    var rngs = meas.findinttrgns(ints, v)
+    var res = -1
+    var maxl = -1
+    Object.keys(rngs).forEach((k) => {
+	if (Math.abs(rngs[k]) > maxl) {
+	    res = rngs[k]+2
+	    maxl = Math.abs(rngs[k])
 	}
     })
     return res
@@ -684,6 +719,11 @@ meas.initSettings = function(x, ev) {
     }
 }
 
+meas.setInputValue = function(x, v) {
+    x.value = v
+    x.dataset.tdone = 0
+}
+
 meas.onChangeSettings = function(x, ev) {
     console.log('onchange settings', x.id)
     var form = x.form
@@ -705,10 +745,10 @@ meas.onChangeSettings = function(x, ev) {
 	    pktBytes = 20
 	}
 	var effSR = Number(form['sample-rate'].value) / Number(form['packet-decimation'].value)
-	form['effsrate'].value = effSR
+	meas.setInputValue(form['effsrate'], effSR)
 	var drate = effSR * pktBytes / 1000
-	form['datarate'].value = drate
-	if (drate > 160) {
+	meas.setInputValue(form['datarate'], drate)
+	if (drate > 240) {
 	    form['datarate'].style.background = '#80000030'
 	    form['datarate'].style.border     = '0.1em solid red'
 	} else {
@@ -790,7 +830,7 @@ meas.onChangeSettings = function(x, ev) {
 	var sr = Number(form['sample-rate'].value)
 	var divi = Number(x.value.split('/')[1])
 	var effBW = (sr / divi) / 2
-	form['gyro-filter-eff-bandwidth'].value = effBW
+	meas.setInputValue(form['gyro-filter-eff-bandwidth'], effBW)
 
     } else if (x.id == 'accel-filter-low-latency') {
 	var bw = form['accel-filter-bandwidth']
@@ -805,15 +845,17 @@ meas.onChangeSettings = function(x, ev) {
 	var sr = Number(form['sample-rate'].value)
 	var divi = Number(x.value.split('/')[1])
 	var effBW = (sr / divi) / 2
-	form['accel-filter-eff-bandwidth'].value = effBW
+	meas.setInputValue(form['accel-filter-eff-bandwidth'], effBW)
 
     } else if (x.id == 'temp0') {
 	x.checked = true
     }
+    tl.update(document)
 }
 
 meas.submitSettings = function(ev) {
     var settingsForm = ev.target
+    meas.untranslateNValues(settingsForm)
     var valdoc = xc.getCGIXML(settingsForm)
     var updatexlp = xlp.mkXLP(['update-settings.xsl'], '/main/getf/')
     var indoc = xc.getXDoc([valdoc, xc.getMarkup(xc.docs['settings'])].join(''), 'settings-update')
@@ -840,10 +882,10 @@ meas.submitSettings = function(ev) {
 
 			    myframes.renderRespHandler(respdoc, resp, function() {
 				console.log('XML settings updated: page updated')
-				renderPostProc(ev, resp, undefined, function (a, b) {
+				renderPostProc(ev, resp, function (a, b) {
 				    meas.note('Settings updated')
 				    console.log('Settings updated', a, b)
-				})
+				}, true)
 			    })
 
 			})
@@ -886,14 +928,18 @@ meas.submitWiFiSettings = function(ev) {
     })
 }
 
-meas.submitLimitSettings = function(ev) {
-    var settingsForm = ev.target
+meas.untranslateNValues = function(settingsForm) {
     for (var f in settingsForm.elements) {
 	var input = settingsForm.elements[f]
 	if (input.value) {
 	    input.value = input.value.replace(',', '.')
 	}
     }
+}
+
+meas.submitLimitSettings = function(ev) {
+    var settingsForm = ev.target
+    meas.untranslateNValues(settingsForm)
     var valdoc = xc.getCGIXML(settingsForm)
     var updatexlp = xlp.mkXLP(['update-limits.xsl'], '/main/getf/')
     var indoc = xc.getXDoc([valdoc, xc.getMarkup(xc.docs['limits'])].join(''), 'limits-update')
@@ -1365,6 +1411,11 @@ meas.psLatestMeasurements = function(text) {
 }
 
 meas.psLiveMeasurement = function(data, el) {
+    if (data.length>0 && data[0] == '<') {
+	console.log('no CSV data')
+	return
+    }
+
     var ppFunc = function() {
 //	console.log('live meas poll done')
     }
@@ -1494,6 +1545,19 @@ meas.onchangeHandler = function(event) {
 
 document.addEventListener('change', meas.onchangeHandler)
 
+meas.startFetch = function(ev) {
+    //meas.curfetch = meas.note('Load' + ev.detail.url)
+}
+
+meas.endFetch = function(ev) {
+    if (meas.curfetch) {
+	meas.curfetch()
+    }
+}
+
+document.addEventListener('xc-startfetch', meas.startFetch)
+document.addEventListener('xc-endfetch', meas.endFetch)
+
 tl.apptable({
     acc: { de: 'Beschleu&#xad;ni&#xad;gung', en: 'Acceleration'},
     gyro: {de: 'Gyro&#xad;skop', en: 'Gyroscope' },
@@ -1562,6 +1626,8 @@ tl.apptable({
     dlr: {de: 'Datenbereich herunterladen', en: 'Download data range'},
 
     del: {de: 'Löschen', en: 'Delete'},
+    delm: {de: 'Ausgewählte löschen', en: 'Delete selected'},
+    delp: {de: 'Dateiname', en: 'File name'},
     cwif: {de: 'Neues WiFi einrichten', en: 'Configure new WiFi setting'},
     wifs: {de: 'WiFi Einstellungen', en: 'WiFi Settings'},
     wifn: {de: 'WiFi Name (ESSID)', en: 'WiFi name (ESSID)'},
@@ -1668,9 +1734,14 @@ tl.apptable({
     stn27: {de: 'Frei lassen für Werkseinstellungen, oder', en: 'Leave blank to use factory trimmed parameters, or'},
     stn28: {de: 'vom Sensor', en: 'from sensor'},
     stn29: {de: 'Erweitert', en: 'Advanced'},
-    stn30: {de: 'Ereignis beended', en: 'event ended'},
+    stn30: {de: 'Ereignis beended', en: 'Event ended'},
     stn31: {de: 'Schließen', en: 'Close'},
     stn32: {de: 'Aktualisieren', en: 'Reload'},
+    stn33: {de: 'Kalibrieren', en: 'Calibrate'},
+    stn34: {de: 'der Gyroskop Versatzwerte', en: 'gyroscope offsets'},
+    stn35: {de: 'Achsen invertieren', en: 'Invert Axes'},
+    stn36: {de: 'Keine Ereignisse', en: 'No events'},
+    stn37: {de: 'Liste der Grenzereignisse', en: 'List of limit events'},
 
     osr1:  {de: 'Messfrequenz/2',  en: 'Sample rate/2'},
     osr2:  {de: 'Messfrequenz/4',  en: 'Sample rate/4'},
@@ -1708,9 +1779,9 @@ meas.showCSV = function(text) {
     return table
 }
 
-meas.psEventList = function(text) {
+meas.psEventListInner = function(text) {
     if (text.length == 0) {
-	return '<span class="tlt">no events</span>'
+	return '<span class="tlt">No events</span>'
     }
 
     var classes = [ 'alarm-low', 'warn-low', 'ok-low', 'warn-high', 'alarm-high' ]
@@ -1721,6 +1792,10 @@ meas.psEventList = function(text) {
     var items = text.split('\n')
     items = items.slice(0, -1)
 
+    if (items.length == 0) {
+	return '<span class="tlt">No events</span>'
+    }
+
     var elems = items.map((x)=> x.split(';')).reverse()
 
 //    var eHeader = elems[0]
@@ -1748,23 +1823,29 @@ meas.psEventList = function(text) {
 		}
 		var unit = meas.getUnit(evData[i].source, meas.events.headerInfo)
 		s += '<td>' + meas.translateMeasName(evData[i].source).replace('_', ' ') + '</td>'
-		s += '<td class="' + tmap(evData[i].type) + '">' + evData[i].value + ' ' + unit + '</td>'
+		s += '<td class="' + tmap(evData[i].type) + '"><span title="' + evData[i].value + ' ' + unit + '" class="tln">' + evData[i].value + '</span> <span class="unit">' + unit + '</span></td>'
 		//	s += '<td class="' + tmap(evData.type) + '">&nbsp;</td>'
 		res += '<tr class="event">' + s + '</tr>'
 	    }
 	} else {
 	    var s = '<td class="ts">' + ts + '</td>'
-	    s += '<td class="tlt">event ended</td><td></td>'
+	    s += '<td class="tlt">Event ended</td><td></td>'
 	    res = '<tr class="noevent">' + s + '</tr>'
 	}
 	return res
     })
 
     var tbl = '<table>' + rows.join('\n') + '</table>'
-    var html = '<div class="events">'
-    html += '<a class="xc-nocatch floatr tlt" href="#" onclick="meas.updateEventsList(event)">Reload</a> '
-    html += '<a class="xc-nocatch floatr tlt" href="#" onclick="meas.closeDynamicSection(event)">Close</a>'
-    html += tbl
+    return tbl
+}
+
+meas.psEventList = function(text) {
+    var inner = meas.psEventListInner(text)
+    var html = '<div class="events dynsec">'
+    html += '<h4 class="tlt">List of limit events</h4>'
+    html += '<div><a class="xc-nocatch floatr tlt" href="#" onclick="meas.updateEventsList(event)">Reload</a> '
+    html += '<a class="xc-nocatch floatr tlt" href="#" onclick="meas.closeDynamicSection(event)">Close</a></div>'
+    html += '<div>' + inner + '</div>'
     html += '</div>'
     return html
 }
@@ -1779,8 +1860,15 @@ meas.inject = function(id, html, ev, done) {
     })
 }
 
+meas.hideResultView = function() {
+    meas.hideChildren('.charts')
+    document.querySelector('#result-dispsels').innerHTML = ''
+    document.querySelector('#result-nmeas').innerHTML = ''
+}
+
 meas.updateEventsList = function(ev) {
     var fname = meas.events.fname
+    meas.hideResultView()
     xlp.sendGet('/main/range?path=' + fname + '&start=' + meas.events.range[0] + '&end=' + meas.events.range[1], function(s, resp) {
 	if (s != 0) { return }
 	xlp.sendGet('/main/head?path=' + meas.events.measname + '&n=1', function(s, respH) {
@@ -1791,6 +1879,7 @@ meas.updateEventsList = function(ev) {
 	    var html = meas.psEventList(resp.responseText)
 	    meas.inject('event-view', html, ev, function(a,b) {
 		console.log('Events list updated')
+		window.scrollTo(0,100)
 	    })
 	})
     })
@@ -1802,6 +1891,32 @@ meas.loadEvents = function(fname, ev) {
     meas.updateEventsList(ev)
 }
 
+meas.findAncestorByClass = function(x, cname) {
+    if (x.classList.contains(cname)) {
+	return x
+    } else if (x.parentElement) {
+	return meas.findAncestorByClass(x.parentElement, cname)
+    }
+}
+
 meas.closeDynamicSection = function(event) {
-    event.target.parentElement.innerHTML = ''
+    var x = event.target
+    var ctarget = x.parentElement
+    if (x.dataset.target) {
+	ctarget = document.querySelector('#' + x.dataset.target)
+    } else {
+	var ct2 = meas.findAncestorByClass(x, 'dynsec')
+	if (ct2) {
+	    ctarget = ct2
+	}
+    }
+    ctarget.innerHTML = ''
+}
+
+meas.measListSelectAll = function(ev) {
+    var form = document.forms['deleteitems']
+    var x = ev.target
+    for (var i = 0; i < form.elements.length; ++i) {
+	form.elements[i].checked = x.checked
+    }
 }
